# -*- coding: utf-8 -*-

# Description: Tests for the lib.url module
#
# Copyright:
# Copyright (C) 2011 Bundesamt fur Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.


import os
import unittest
from mapwoc.lib import url

class TestValidateURL(unittest.TestCase):
    def test_invalidURLS(self):
        urls = [ "gubbelgubbel",
                 "www.gubbel.de",
                 "httx://gubbel.gu",
                 "ftp://gubbel.gu",
                 "http:/gubbel.gu",
                 "http//gubbel.gu",
                 "http://gubbel:gu",
                 "http://gubbel,gu",
                 "http://gubbel",
                 "javascript:alert(\"Hello World!\")",
                 "http://javascript:alert(\"Hello World!\)",
                 "httpoeox://gubbel.gu",
                 "http://256.256.256.100:12",
                 "http://-1.-1.-1.-1:0",
                 "http://5.5.5:0",
                 "http://1.2.3.4:12345678",
                 """http://dies/
                    ist nicht valide""",
                 "http://gubbel\n.de",
                 "http:// gubbel.gu",
                 "",
                 "http://" ]
        for u in urls:
            self.assertEqual(url.validate_URL(u), False, u)

    def test_ipv6(self):
         u = "http://[2001:0db8:85a3:08d3:1319:8a2e:dead:beef]:8080"
         self.assertEqual(url.validate_URL(u), False, u)

    def test_localdomain(self):
        urls = [ "http://localhost",
                 "http://localhost:1235",
                 "http://gubbel:1235"]
        for u in urls:
            self.assertEqual(url.validate_URL(u), False, u)

    def test_ipv4(self):
        urls = [ "http://127.0.0.1",
                 "http://127.0.0.1:12312" ]
        for u in urls:
            self.assertEqual(url.validate_URL(u), True, u)

    def test_validURLS(self):
        urls = [ "http://gubbel.gu",
                 "http://gubbel.gu/",
                 "https://gubbel.gu",
                 "https://gubbel.gu/gubbel",
                 "https://gubbel.gu/gubbel.xyz",
                 "https://gubbel.gu/gubbel/gubbel/gubbel",
                 "https://www.gubbel.gu",
                 "https://www.gubbel.gu/?=abc",
                 "https://www.gubbel.gu/abc?=fgh",
                 "http://a.intevation.de" ]
        for u in urls:
            self.assertEqual(url.validate_URL(u), True, u)
